import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleAssuredWorkloadsWorkloadConfig extends cdktf.TerraformMetaArguments {
    /**
    * Required. Input only. The billing account used for the resources which are direct children of workload. This billing account is initially associated with the resources created as part of Workload creation. After the initial creation of these resources, the customer can change the assigned billing account. The resource name has the form `billingAccounts/{billing_account_id}`. For example, 'billingAccounts/012345-567890-ABCDEF`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#billing_account GoogleAssuredWorkloadsWorkload#billing_account}
    */
    readonly billingAccount: string;
    /**
    * Required. Immutable. Compliance Regime associated with this workload. Possible values: COMPLIANCE_REGIME_UNSPECIFIED, IL4, CJIS, FEDRAMP_HIGH, FEDRAMP_MODERATE, US_REGIONAL_ACCESS
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#compliance_regime GoogleAssuredWorkloadsWorkload#compliance_regime}
    */
    readonly complianceRegime: string;
    /**
    * Required. The user-assigned display name of the Workload. When present it must be between 4 to 30 characters. Allowed characters are: lowercase and uppercase letters, numbers, hyphen, and spaces. Example: My Workload
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#display_name GoogleAssuredWorkloadsWorkload#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#id GoogleAssuredWorkloadsWorkload#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional. Labels applied to the workload.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#labels GoogleAssuredWorkloadsWorkload#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location for the resource
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#location GoogleAssuredWorkloadsWorkload#location}
    */
    readonly location: string;
    /**
    * The organization for the resource
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#organization GoogleAssuredWorkloadsWorkload#organization}
    */
    readonly organization: string;
    /**
    * Input only. The parent resource for the resources managed by this Assured Workload. May be either an organization or a folder. Must be the same or a child of the Workload parent. If not specified all resources are created under the Workload parent. Formats: folders/{folder_id}, organizations/{organization_id}
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#provisioned_resources_parent GoogleAssuredWorkloadsWorkload#provisioned_resources_parent}
    */
    readonly provisionedResourcesParent?: string;
    /**
    * kms_settings block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#kms_settings GoogleAssuredWorkloadsWorkload#kms_settings}
    */
    readonly kmsSettings?: GoogleAssuredWorkloadsWorkloadKmsSettings;
    /**
    * resource_settings block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#resource_settings GoogleAssuredWorkloadsWorkload#resource_settings}
    */
    readonly resourceSettings?: GoogleAssuredWorkloadsWorkloadResourceSettings[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#timeouts GoogleAssuredWorkloadsWorkload#timeouts}
    */
    readonly timeouts?: GoogleAssuredWorkloadsWorkloadTimeouts;
}
export interface GoogleAssuredWorkloadsWorkloadResources {
}
export declare function googleAssuredWorkloadsWorkloadResourcesToTerraform(struct?: GoogleAssuredWorkloadsWorkloadResources): any;
export declare class GoogleAssuredWorkloadsWorkloadResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleAssuredWorkloadsWorkloadResources | undefined;
    set internalValue(value: GoogleAssuredWorkloadsWorkloadResources | undefined);
    get resourceId(): number;
    get resourceType(): string;
}
export declare class GoogleAssuredWorkloadsWorkloadResourcesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleAssuredWorkloadsWorkloadResourcesOutputReference;
}
export interface GoogleAssuredWorkloadsWorkloadKmsSettings {
    /**
    * Required. Input only. Immutable. The time at which the Key Management Service will automatically create a new version of the crypto key and mark it as the primary.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#next_rotation_time GoogleAssuredWorkloadsWorkload#next_rotation_time}
    */
    readonly nextRotationTime: string;
    /**
    * Required. Input only. Immutable. will be advanced by this period when the Key Management Service automatically rotates a key. Must be at least 24 hours and at most 876,000 hours.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#rotation_period GoogleAssuredWorkloadsWorkload#rotation_period}
    */
    readonly rotationPeriod: string;
}
export declare function googleAssuredWorkloadsWorkloadKmsSettingsToTerraform(struct?: GoogleAssuredWorkloadsWorkloadKmsSettingsOutputReference | GoogleAssuredWorkloadsWorkloadKmsSettings): any;
export declare class GoogleAssuredWorkloadsWorkloadKmsSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleAssuredWorkloadsWorkloadKmsSettings | undefined;
    set internalValue(value: GoogleAssuredWorkloadsWorkloadKmsSettings | undefined);
    private _nextRotationTime?;
    get nextRotationTime(): string;
    set nextRotationTime(value: string);
    get nextRotationTimeInput(): string | undefined;
    private _rotationPeriod?;
    get rotationPeriod(): string;
    set rotationPeriod(value: string);
    get rotationPeriodInput(): string | undefined;
}
export interface GoogleAssuredWorkloadsWorkloadResourceSettings {
    /**
    * Resource identifier. For a project this represents project_number. If the project is already taken, the workload creation will fail.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#resource_id GoogleAssuredWorkloadsWorkload#resource_id}
    */
    readonly resourceId?: string;
    /**
    * Indicates the type of resource. This field should be specified to correspond the id to the right project type (CONSUMER_PROJECT or ENCRYPTION_KEYS_PROJECT) Possible values: RESOURCE_TYPE_UNSPECIFIED, CONSUMER_PROJECT, ENCRYPTION_KEYS_PROJECT, KEYRING, CONSUMER_FOLDER
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#resource_type GoogleAssuredWorkloadsWorkload#resource_type}
    */
    readonly resourceType?: string;
}
export declare function googleAssuredWorkloadsWorkloadResourceSettingsToTerraform(struct?: GoogleAssuredWorkloadsWorkloadResourceSettings | cdktf.IResolvable): any;
export declare class GoogleAssuredWorkloadsWorkloadResourceSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleAssuredWorkloadsWorkloadResourceSettings | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleAssuredWorkloadsWorkloadResourceSettings | cdktf.IResolvable | undefined);
    private _resourceId?;
    get resourceId(): string;
    set resourceId(value: string);
    resetResourceId(): void;
    get resourceIdInput(): string | undefined;
    private _resourceType?;
    get resourceType(): string;
    set resourceType(value: string);
    resetResourceType(): void;
    get resourceTypeInput(): string | undefined;
}
export declare class GoogleAssuredWorkloadsWorkloadResourceSettingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleAssuredWorkloadsWorkloadResourceSettings[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleAssuredWorkloadsWorkloadResourceSettingsOutputReference;
}
export interface GoogleAssuredWorkloadsWorkloadTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#create GoogleAssuredWorkloadsWorkload#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#delete GoogleAssuredWorkloadsWorkload#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload#update GoogleAssuredWorkloadsWorkload#update}
    */
    readonly update?: string;
}
export declare function googleAssuredWorkloadsWorkloadTimeoutsToTerraform(struct?: GoogleAssuredWorkloadsWorkloadTimeoutsOutputReference | GoogleAssuredWorkloadsWorkloadTimeouts | cdktf.IResolvable): any;
export declare class GoogleAssuredWorkloadsWorkloadTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleAssuredWorkloadsWorkloadTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleAssuredWorkloadsWorkloadTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload google_assured_workloads_workload}
*/
export declare class GoogleAssuredWorkloadsWorkload extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_assured_workloads_workload";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_assured_workloads_workload google_assured_workloads_workload} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleAssuredWorkloadsWorkloadConfig
    */
    constructor(scope: Construct, id: string, config: GoogleAssuredWorkloadsWorkloadConfig);
    private _billingAccount?;
    get billingAccount(): string;
    set billingAccount(value: string);
    get billingAccountInput(): string | undefined;
    private _complianceRegime?;
    get complianceRegime(): string;
    set complianceRegime(value: string);
    get complianceRegimeInput(): string | undefined;
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _provisionedResourcesParent?;
    get provisionedResourcesParent(): string;
    set provisionedResourcesParent(value: string);
    resetProvisionedResourcesParent(): void;
    get provisionedResourcesParentInput(): string | undefined;
    private _resources;
    get resources(): GoogleAssuredWorkloadsWorkloadResourcesList;
    private _kmsSettings;
    get kmsSettings(): GoogleAssuredWorkloadsWorkloadKmsSettingsOutputReference;
    putKmsSettings(value: GoogleAssuredWorkloadsWorkloadKmsSettings): void;
    resetKmsSettings(): void;
    get kmsSettingsInput(): GoogleAssuredWorkloadsWorkloadKmsSettings | undefined;
    private _resourceSettings;
    get resourceSettings(): GoogleAssuredWorkloadsWorkloadResourceSettingsList;
    putResourceSettings(value: GoogleAssuredWorkloadsWorkloadResourceSettings[] | cdktf.IResolvable): void;
    resetResourceSettings(): void;
    get resourceSettingsInput(): cdktf.IResolvable | GoogleAssuredWorkloadsWorkloadResourceSettings[] | undefined;
    private _timeouts;
    get timeouts(): GoogleAssuredWorkloadsWorkloadTimeoutsOutputReference;
    putTimeouts(value: GoogleAssuredWorkloadsWorkloadTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleAssuredWorkloadsWorkloadTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
