import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleCloudSchedulerJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * The deadline for job attempts. If the request handler does not respond by this deadline then the request is
  cancelled and the attempt is marked as a DEADLINE_EXCEEDED failure. The failed attempt can be viewed in
  execution logs. Cloud Scheduler will retry the job according to the RetryConfig.
  The allowed duration for this deadline is:
  * For HTTP targets, between 15 seconds and 30 minutes.
  * For App Engine HTTP targets, between 15 seconds and 24 hours.
  * **Note**: For PubSub targets, this field is ignored - setting it will introduce an unresolvable diff.
  A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s"
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#attempt_deadline GoogleCloudSchedulerJob#attempt_deadline}
    */
    readonly attemptDeadline?: string;
    /**
    * A human-readable description for the job.
  This string must not contain more than 500 characters.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#description GoogleCloudSchedulerJob#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#id GoogleCloudSchedulerJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the job.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#name GoogleCloudSchedulerJob#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#project GoogleCloudSchedulerJob#project}
    */
    readonly project?: string;
    /**
    * Region where the scheduler job resides. If it is not provided, Terraform will use the provider default.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#region GoogleCloudSchedulerJob#region}
    */
    readonly region?: string;
    /**
    * Describes the schedule on which the job will be executed.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#schedule GoogleCloudSchedulerJob#schedule}
    */
    readonly schedule?: string;
    /**
    * Specifies the time zone to be used in interpreting schedule.
  The value of this field must be a time zone name from the tz database.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#time_zone GoogleCloudSchedulerJob#time_zone}
    */
    readonly timeZone?: string;
    /**
    * app_engine_http_target block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#app_engine_http_target GoogleCloudSchedulerJob#app_engine_http_target}
    */
    readonly appEngineHttpTarget?: GoogleCloudSchedulerJobAppEngineHttpTarget;
    /**
    * http_target block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#http_target GoogleCloudSchedulerJob#http_target}
    */
    readonly httpTarget?: GoogleCloudSchedulerJobHttpTarget;
    /**
    * pubsub_target block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#pubsub_target GoogleCloudSchedulerJob#pubsub_target}
    */
    readonly pubsubTarget?: GoogleCloudSchedulerJobPubsubTarget;
    /**
    * retry_config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#retry_config GoogleCloudSchedulerJob#retry_config}
    */
    readonly retryConfig?: GoogleCloudSchedulerJobRetryConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#timeouts GoogleCloudSchedulerJob#timeouts}
    */
    readonly timeouts?: GoogleCloudSchedulerJobTimeouts;
}
export interface GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRouting {
    /**
    * App instance.
  By default, the job is sent to an instance which is available when the job is attempted.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#instance GoogleCloudSchedulerJob#instance}
    */
    readonly instance?: string;
    /**
    * App service.
  By default, the job is sent to the service which is the default service when the job is attempted.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#service GoogleCloudSchedulerJob#service}
    */
    readonly service?: string;
    /**
    * App version.
  By default, the job is sent to the version which is the default version when the job is attempted.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#version GoogleCloudSchedulerJob#version}
    */
    readonly version?: string;
}
export declare function googleCloudSchedulerJobAppEngineHttpTargetAppEngineRoutingToTerraform(struct?: GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRoutingOutputReference | GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRouting): any;
export declare class GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRoutingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRouting | undefined;
    set internalValue(value: GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRouting | undefined);
    private _instance?;
    get instance(): string;
    set instance(value: string);
    resetInstance(): void;
    get instanceInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
}
export interface GoogleCloudSchedulerJobAppEngineHttpTarget {
    /**
    * HTTP request body.
  A request body is allowed only if the HTTP method is POST or PUT.
  It will result in invalid argument error to set a body on a job with an incompatible HttpMethod.
  
  A base64-encoded string.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#body GoogleCloudSchedulerJob#body}
    */
    readonly body?: string;
    /**
    * HTTP request headers.
  This map contains the header field names and values.
  Headers can be set when the job is created.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#headers GoogleCloudSchedulerJob#headers}
    */
    readonly headers?: {
        [key: string]: string;
    };
    /**
    * Which HTTP method to use for the request.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#http_method GoogleCloudSchedulerJob#http_method}
    */
    readonly httpMethod?: string;
    /**
    * The relative URI.
  The relative URL must begin with "/" and must be a valid HTTP relative URL.
  It can contain a path, query string arguments, and \# fragments.
  If the relative URL is empty, then the root path "/" will be used.
  No spaces are allowed, and the maximum length allowed is 2083 characters
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#relative_uri GoogleCloudSchedulerJob#relative_uri}
    */
    readonly relativeUri: string;
    /**
    * app_engine_routing block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#app_engine_routing GoogleCloudSchedulerJob#app_engine_routing}
    */
    readonly appEngineRouting?: GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRouting;
}
export declare function googleCloudSchedulerJobAppEngineHttpTargetToTerraform(struct?: GoogleCloudSchedulerJobAppEngineHttpTargetOutputReference | GoogleCloudSchedulerJobAppEngineHttpTarget): any;
export declare class GoogleCloudSchedulerJobAppEngineHttpTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudSchedulerJobAppEngineHttpTarget | undefined;
    set internalValue(value: GoogleCloudSchedulerJobAppEngineHttpTarget | undefined);
    private _body?;
    get body(): string;
    set body(value: string);
    resetBody(): void;
    get bodyInput(): string | undefined;
    private _headers?;
    get headers(): {
        [key: string]: string;
    };
    set headers(value: {
        [key: string]: string;
    });
    resetHeaders(): void;
    get headersInput(): {
        [key: string]: string;
    } | undefined;
    private _httpMethod?;
    get httpMethod(): string;
    set httpMethod(value: string);
    resetHttpMethod(): void;
    get httpMethodInput(): string | undefined;
    private _relativeUri?;
    get relativeUri(): string;
    set relativeUri(value: string);
    get relativeUriInput(): string | undefined;
    private _appEngineRouting;
    get appEngineRouting(): GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRoutingOutputReference;
    putAppEngineRouting(value: GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRouting): void;
    resetAppEngineRouting(): void;
    get appEngineRoutingInput(): GoogleCloudSchedulerJobAppEngineHttpTargetAppEngineRouting | undefined;
}
export interface GoogleCloudSchedulerJobHttpTargetOauthToken {
    /**
    * OAuth scope to be used for generating OAuth access token. If not specified,
  "https://www.googleapis.com/auth/cloud-platform" will be used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#scope GoogleCloudSchedulerJob#scope}
    */
    readonly scope?: string;
    /**
    * Service account email to be used for generating OAuth token.
  The service account must be within the same project as the job.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#service_account_email GoogleCloudSchedulerJob#service_account_email}
    */
    readonly serviceAccountEmail: string;
}
export declare function googleCloudSchedulerJobHttpTargetOauthTokenToTerraform(struct?: GoogleCloudSchedulerJobHttpTargetOauthTokenOutputReference | GoogleCloudSchedulerJobHttpTargetOauthToken): any;
export declare class GoogleCloudSchedulerJobHttpTargetOauthTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudSchedulerJobHttpTargetOauthToken | undefined;
    set internalValue(value: GoogleCloudSchedulerJobHttpTargetOauthToken | undefined);
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string;
    set serviceAccountEmail(value: string);
    get serviceAccountEmailInput(): string | undefined;
}
export interface GoogleCloudSchedulerJobHttpTargetOidcToken {
    /**
    * Audience to be used when generating OIDC token. If not specified,
  the URI specified in target will be used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#audience GoogleCloudSchedulerJob#audience}
    */
    readonly audience?: string;
    /**
    * Service account email to be used for generating OAuth token.
  The service account must be within the same project as the job.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#service_account_email GoogleCloudSchedulerJob#service_account_email}
    */
    readonly serviceAccountEmail: string;
}
export declare function googleCloudSchedulerJobHttpTargetOidcTokenToTerraform(struct?: GoogleCloudSchedulerJobHttpTargetOidcTokenOutputReference | GoogleCloudSchedulerJobHttpTargetOidcToken): any;
export declare class GoogleCloudSchedulerJobHttpTargetOidcTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudSchedulerJobHttpTargetOidcToken | undefined;
    set internalValue(value: GoogleCloudSchedulerJobHttpTargetOidcToken | undefined);
    private _audience?;
    get audience(): string;
    set audience(value: string);
    resetAudience(): void;
    get audienceInput(): string | undefined;
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string;
    set serviceAccountEmail(value: string);
    get serviceAccountEmailInput(): string | undefined;
}
export interface GoogleCloudSchedulerJobHttpTarget {
    /**
    * HTTP request body.
  A request body is allowed only if the HTTP method is POST, PUT, or PATCH.
  It is an error to set body on a job with an incompatible HttpMethod.
  
  A base64-encoded string.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#body GoogleCloudSchedulerJob#body}
    */
    readonly body?: string;
    /**
    * This map contains the header field names and values.
  Repeated headers are not supported, but a header value can contain commas.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#headers GoogleCloudSchedulerJob#headers}
    */
    readonly headers?: {
        [key: string]: string;
    };
    /**
    * Which HTTP method to use for the request.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#http_method GoogleCloudSchedulerJob#http_method}
    */
    readonly httpMethod?: string;
    /**
    * The full URI path that the request will be sent to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#uri GoogleCloudSchedulerJob#uri}
    */
    readonly uri: string;
    /**
    * oauth_token block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#oauth_token GoogleCloudSchedulerJob#oauth_token}
    */
    readonly oauthToken?: GoogleCloudSchedulerJobHttpTargetOauthToken;
    /**
    * oidc_token block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#oidc_token GoogleCloudSchedulerJob#oidc_token}
    */
    readonly oidcToken?: GoogleCloudSchedulerJobHttpTargetOidcToken;
}
export declare function googleCloudSchedulerJobHttpTargetToTerraform(struct?: GoogleCloudSchedulerJobHttpTargetOutputReference | GoogleCloudSchedulerJobHttpTarget): any;
export declare class GoogleCloudSchedulerJobHttpTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudSchedulerJobHttpTarget | undefined;
    set internalValue(value: GoogleCloudSchedulerJobHttpTarget | undefined);
    private _body?;
    get body(): string;
    set body(value: string);
    resetBody(): void;
    get bodyInput(): string | undefined;
    private _headers?;
    get headers(): {
        [key: string]: string;
    };
    set headers(value: {
        [key: string]: string;
    });
    resetHeaders(): void;
    get headersInput(): {
        [key: string]: string;
    } | undefined;
    private _httpMethod?;
    get httpMethod(): string;
    set httpMethod(value: string);
    resetHttpMethod(): void;
    get httpMethodInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
    private _oauthToken;
    get oauthToken(): GoogleCloudSchedulerJobHttpTargetOauthTokenOutputReference;
    putOauthToken(value: GoogleCloudSchedulerJobHttpTargetOauthToken): void;
    resetOauthToken(): void;
    get oauthTokenInput(): GoogleCloudSchedulerJobHttpTargetOauthToken | undefined;
    private _oidcToken;
    get oidcToken(): GoogleCloudSchedulerJobHttpTargetOidcTokenOutputReference;
    putOidcToken(value: GoogleCloudSchedulerJobHttpTargetOidcToken): void;
    resetOidcToken(): void;
    get oidcTokenInput(): GoogleCloudSchedulerJobHttpTargetOidcToken | undefined;
}
export interface GoogleCloudSchedulerJobPubsubTarget {
    /**
    * Attributes for PubsubMessage.
  Pubsub message must contain either non-empty data, or at least one attribute.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#attributes GoogleCloudSchedulerJob#attributes}
    */
    readonly attributes?: {
        [key: string]: string;
    };
    /**
    * The message payload for PubsubMessage.
  Pubsub message must contain either non-empty data, or at least one attribute.
  
   A base64-encoded string.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#data GoogleCloudSchedulerJob#data}
    */
    readonly data?: string;
    /**
    * The full resource name for the Cloud Pub/Sub topic to which
  messages will be published when a job is delivered. ~>**NOTE:**
  The topic name must be in the same format as required by PubSub's
  PublishRequest.name, e.g. 'projects/my-project/topics/my-topic'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#topic_name GoogleCloudSchedulerJob#topic_name}
    */
    readonly topicName: string;
}
export declare function googleCloudSchedulerJobPubsubTargetToTerraform(struct?: GoogleCloudSchedulerJobPubsubTargetOutputReference | GoogleCloudSchedulerJobPubsubTarget): any;
export declare class GoogleCloudSchedulerJobPubsubTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudSchedulerJobPubsubTarget | undefined;
    set internalValue(value: GoogleCloudSchedulerJobPubsubTarget | undefined);
    private _attributes?;
    get attributes(): {
        [key: string]: string;
    };
    set attributes(value: {
        [key: string]: string;
    });
    resetAttributes(): void;
    get attributesInput(): {
        [key: string]: string;
    } | undefined;
    private _data?;
    get data(): string;
    set data(value: string);
    resetData(): void;
    get dataInput(): string | undefined;
    private _topicName?;
    get topicName(): string;
    set topicName(value: string);
    get topicNameInput(): string | undefined;
}
export interface GoogleCloudSchedulerJobRetryConfig {
    /**
    * The maximum amount of time to wait before retrying a job after it fails.
  A duration in seconds with up to nine fractional digits, terminated by 's'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#max_backoff_duration GoogleCloudSchedulerJob#max_backoff_duration}
    */
    readonly maxBackoffDuration?: string;
    /**
    * The time between retries will double maxDoublings times.
  A job's retry interval starts at minBackoffDuration,
  then doubles maxDoublings times, then increases linearly,
  and finally retries retries at intervals of maxBackoffDuration up to retryCount times.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#max_doublings GoogleCloudSchedulerJob#max_doublings}
    */
    readonly maxDoublings?: number;
    /**
    * The time limit for retrying a failed job, measured from time when an execution was first attempted.
  If specified with retryCount, the job will be retried until both limits are reached.
  A duration in seconds with up to nine fractional digits, terminated by 's'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#max_retry_duration GoogleCloudSchedulerJob#max_retry_duration}
    */
    readonly maxRetryDuration?: string;
    /**
    * The minimum amount of time to wait before retrying a job after it fails.
  A duration in seconds with up to nine fractional digits, terminated by 's'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#min_backoff_duration GoogleCloudSchedulerJob#min_backoff_duration}
    */
    readonly minBackoffDuration?: string;
    /**
    * The number of attempts that the system will make to run a
  job using the exponential backoff procedure described by maxDoublings.
  Values greater than 5 and negative values are not allowed.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#retry_count GoogleCloudSchedulerJob#retry_count}
    */
    readonly retryCount?: number;
}
export declare function googleCloudSchedulerJobRetryConfigToTerraform(struct?: GoogleCloudSchedulerJobRetryConfigOutputReference | GoogleCloudSchedulerJobRetryConfig): any;
export declare class GoogleCloudSchedulerJobRetryConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudSchedulerJobRetryConfig | undefined;
    set internalValue(value: GoogleCloudSchedulerJobRetryConfig | undefined);
    private _maxBackoffDuration?;
    get maxBackoffDuration(): string;
    set maxBackoffDuration(value: string);
    resetMaxBackoffDuration(): void;
    get maxBackoffDurationInput(): string | undefined;
    private _maxDoublings?;
    get maxDoublings(): number;
    set maxDoublings(value: number);
    resetMaxDoublings(): void;
    get maxDoublingsInput(): number | undefined;
    private _maxRetryDuration?;
    get maxRetryDuration(): string;
    set maxRetryDuration(value: string);
    resetMaxRetryDuration(): void;
    get maxRetryDurationInput(): string | undefined;
    private _minBackoffDuration?;
    get minBackoffDuration(): string;
    set minBackoffDuration(value: string);
    resetMinBackoffDuration(): void;
    get minBackoffDurationInput(): string | undefined;
    private _retryCount?;
    get retryCount(): number;
    set retryCount(value: number);
    resetRetryCount(): void;
    get retryCountInput(): number | undefined;
}
export interface GoogleCloudSchedulerJobTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#create GoogleCloudSchedulerJob#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#delete GoogleCloudSchedulerJob#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job#update GoogleCloudSchedulerJob#update}
    */
    readonly update?: string;
}
export declare function googleCloudSchedulerJobTimeoutsToTerraform(struct?: GoogleCloudSchedulerJobTimeoutsOutputReference | GoogleCloudSchedulerJobTimeouts | cdktf.IResolvable): any;
export declare class GoogleCloudSchedulerJobTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudSchedulerJobTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudSchedulerJobTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job google_cloud_scheduler_job}
*/
export declare class GoogleCloudSchedulerJob extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_cloud_scheduler_job";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_scheduler_job google_cloud_scheduler_job} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleCloudSchedulerJobConfig
    */
    constructor(scope: Construct, id: string, config: GoogleCloudSchedulerJobConfig);
    private _attemptDeadline?;
    get attemptDeadline(): string;
    set attemptDeadline(value: string);
    resetAttemptDeadline(): void;
    get attemptDeadlineInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _schedule?;
    get schedule(): string;
    set schedule(value: string);
    resetSchedule(): void;
    get scheduleInput(): string | undefined;
    private _timeZone?;
    get timeZone(): string;
    set timeZone(value: string);
    resetTimeZone(): void;
    get timeZoneInput(): string | undefined;
    private _appEngineHttpTarget;
    get appEngineHttpTarget(): GoogleCloudSchedulerJobAppEngineHttpTargetOutputReference;
    putAppEngineHttpTarget(value: GoogleCloudSchedulerJobAppEngineHttpTarget): void;
    resetAppEngineHttpTarget(): void;
    get appEngineHttpTargetInput(): GoogleCloudSchedulerJobAppEngineHttpTarget | undefined;
    private _httpTarget;
    get httpTarget(): GoogleCloudSchedulerJobHttpTargetOutputReference;
    putHttpTarget(value: GoogleCloudSchedulerJobHttpTarget): void;
    resetHttpTarget(): void;
    get httpTargetInput(): GoogleCloudSchedulerJobHttpTarget | undefined;
    private _pubsubTarget;
    get pubsubTarget(): GoogleCloudSchedulerJobPubsubTargetOutputReference;
    putPubsubTarget(value: GoogleCloudSchedulerJobPubsubTarget): void;
    resetPubsubTarget(): void;
    get pubsubTargetInput(): GoogleCloudSchedulerJobPubsubTarget | undefined;
    private _retryConfig;
    get retryConfig(): GoogleCloudSchedulerJobRetryConfigOutputReference;
    putRetryConfig(value: GoogleCloudSchedulerJobRetryConfig): void;
    resetRetryConfig(): void;
    get retryConfigInput(): GoogleCloudSchedulerJobRetryConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleCloudSchedulerJobTimeoutsOutputReference;
    putTimeouts(value: GoogleCloudSchedulerJobTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleCloudSchedulerJobTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
