import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleCloudfunctions2FunctionConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-provided description of a function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#description GoogleCloudfunctions2Function#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#id GoogleCloudfunctions2Function#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A set of key/value label pairs associated with this Cloud Function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#labels GoogleCloudfunctions2Function#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location of this cloud function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#location GoogleCloudfunctions2Function#location}
    */
    readonly location?: string;
    /**
    * A user-defined name of the function. Function names must
  be unique globally and match pattern 'projects/*\/locations/*\/functions/*'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#name GoogleCloudfunctions2Function#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#project GoogleCloudfunctions2Function#project}
    */
    readonly project?: string;
    /**
    * build_config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#build_config GoogleCloudfunctions2Function#build_config}
    */
    readonly buildConfig?: GoogleCloudfunctions2FunctionBuildConfig;
    /**
    * event_trigger block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#event_trigger GoogleCloudfunctions2Function#event_trigger}
    */
    readonly eventTrigger?: GoogleCloudfunctions2FunctionEventTrigger;
    /**
    * service_config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#service_config GoogleCloudfunctions2Function#service_config}
    */
    readonly serviceConfig?: GoogleCloudfunctions2FunctionServiceConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#timeouts GoogleCloudfunctions2Function#timeouts}
    */
    readonly timeouts?: GoogleCloudfunctions2FunctionTimeouts;
}
export interface GoogleCloudfunctions2FunctionBuildConfigSourceRepoSource {
    /**
    * Regex matching branches to build.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#branch_name GoogleCloudfunctions2Function#branch_name}
    */
    readonly branchName?: string;
    /**
    * Regex matching tags to build.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#commit_sha GoogleCloudfunctions2Function#commit_sha}
    */
    readonly commitSha?: string;
    /**
    * Directory, relative to the source root, in which to run the build.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#dir GoogleCloudfunctions2Function#dir}
    */
    readonly dir?: string;
    /**
    * Only trigger a build if the revision regex does
  NOT match the revision regex.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#invert_regex GoogleCloudfunctions2Function#invert_regex}
    */
    readonly invertRegex?: boolean | cdktf.IResolvable;
    /**
    * ID of the project that owns the Cloud Source Repository. If omitted, the
  project ID requesting the build is assumed.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#project_id GoogleCloudfunctions2Function#project_id}
    */
    readonly projectId?: string;
    /**
    * Name of the Cloud Source Repository.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#repo_name GoogleCloudfunctions2Function#repo_name}
    */
    readonly repoName?: string;
    /**
    * Regex matching tags to build.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#tag_name GoogleCloudfunctions2Function#tag_name}
    */
    readonly tagName?: string;
}
export declare function googleCloudfunctions2FunctionBuildConfigSourceRepoSourceToTerraform(struct?: GoogleCloudfunctions2FunctionBuildConfigSourceRepoSourceOutputReference | GoogleCloudfunctions2FunctionBuildConfigSourceRepoSource): any;
export declare class GoogleCloudfunctions2FunctionBuildConfigSourceRepoSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudfunctions2FunctionBuildConfigSourceRepoSource | undefined;
    set internalValue(value: GoogleCloudfunctions2FunctionBuildConfigSourceRepoSource | undefined);
    private _branchName?;
    get branchName(): string;
    set branchName(value: string);
    resetBranchName(): void;
    get branchNameInput(): string | undefined;
    private _commitSha?;
    get commitSha(): string;
    set commitSha(value: string);
    resetCommitSha(): void;
    get commitShaInput(): string | undefined;
    private _dir?;
    get dir(): string;
    set dir(value: string);
    resetDir(): void;
    get dirInput(): string | undefined;
    private _invertRegex?;
    get invertRegex(): boolean | cdktf.IResolvable;
    set invertRegex(value: boolean | cdktf.IResolvable);
    resetInvertRegex(): void;
    get invertRegexInput(): boolean | cdktf.IResolvable | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _repoName?;
    get repoName(): string;
    set repoName(value: string);
    resetRepoName(): void;
    get repoNameInput(): string | undefined;
    private _tagName?;
    get tagName(): string;
    set tagName(value: string);
    resetTagName(): void;
    get tagNameInput(): string | undefined;
}
export interface GoogleCloudfunctions2FunctionBuildConfigSourceStorageSource {
    /**
    * Google Cloud Storage bucket containing the source
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#bucket GoogleCloudfunctions2Function#bucket}
    */
    readonly bucket?: string;
    /**
    * Google Cloud Storage generation for the object. If the generation
  is omitted, the latest generation will be used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#generation GoogleCloudfunctions2Function#generation}
    */
    readonly generation?: number;
    /**
    * Google Cloud Storage object containing the source.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#object GoogleCloudfunctions2Function#object}
    */
    readonly object?: string;
}
export declare function googleCloudfunctions2FunctionBuildConfigSourceStorageSourceToTerraform(struct?: GoogleCloudfunctions2FunctionBuildConfigSourceStorageSourceOutputReference | GoogleCloudfunctions2FunctionBuildConfigSourceStorageSource): any;
export declare class GoogleCloudfunctions2FunctionBuildConfigSourceStorageSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudfunctions2FunctionBuildConfigSourceStorageSource | undefined;
    set internalValue(value: GoogleCloudfunctions2FunctionBuildConfigSourceStorageSource | undefined);
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    resetBucket(): void;
    get bucketInput(): string | undefined;
    private _generation?;
    get generation(): number;
    set generation(value: number);
    resetGeneration(): void;
    get generationInput(): number | undefined;
    private _object?;
    get object(): string;
    set object(value: string);
    resetObject(): void;
    get objectInput(): string | undefined;
}
export interface GoogleCloudfunctions2FunctionBuildConfigSource {
    /**
    * repo_source block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#repo_source GoogleCloudfunctions2Function#repo_source}
    */
    readonly repoSource?: GoogleCloudfunctions2FunctionBuildConfigSourceRepoSource;
    /**
    * storage_source block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#storage_source GoogleCloudfunctions2Function#storage_source}
    */
    readonly storageSource?: GoogleCloudfunctions2FunctionBuildConfigSourceStorageSource;
}
export declare function googleCloudfunctions2FunctionBuildConfigSourceToTerraform(struct?: GoogleCloudfunctions2FunctionBuildConfigSourceOutputReference | GoogleCloudfunctions2FunctionBuildConfigSource): any;
export declare class GoogleCloudfunctions2FunctionBuildConfigSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudfunctions2FunctionBuildConfigSource | undefined;
    set internalValue(value: GoogleCloudfunctions2FunctionBuildConfigSource | undefined);
    private _repoSource;
    get repoSource(): GoogleCloudfunctions2FunctionBuildConfigSourceRepoSourceOutputReference;
    putRepoSource(value: GoogleCloudfunctions2FunctionBuildConfigSourceRepoSource): void;
    resetRepoSource(): void;
    get repoSourceInput(): GoogleCloudfunctions2FunctionBuildConfigSourceRepoSource | undefined;
    private _storageSource;
    get storageSource(): GoogleCloudfunctions2FunctionBuildConfigSourceStorageSourceOutputReference;
    putStorageSource(value: GoogleCloudfunctions2FunctionBuildConfigSourceStorageSource): void;
    resetStorageSource(): void;
    get storageSourceInput(): GoogleCloudfunctions2FunctionBuildConfigSourceStorageSource | undefined;
}
export interface GoogleCloudfunctions2FunctionBuildConfig {
    /**
    * User managed repository created in Artifact Registry optionally with a customer managed encryption key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#docker_repository GoogleCloudfunctions2Function#docker_repository}
    */
    readonly dockerRepository?: string;
    /**
    * The name of the function (as defined in source code) that will be executed.
  Defaults to the resource name suffix, if not specified. For backward
  compatibility, if function with given name is not found, then the system
  will try to use function named "function". For Node.js this is name of a
  function exported by the module specified in source_location.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#entry_point GoogleCloudfunctions2Function#entry_point}
    */
    readonly entryPoint?: string;
    /**
    * User-provided build-time environment variables for the function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#environment_variables GoogleCloudfunctions2Function#environment_variables}
    */
    readonly environmentVariables?: {
        [key: string]: string;
    };
    /**
    * The runtime in which to run the function. Required when deploying a new
  function, optional when updating an existing function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#runtime GoogleCloudfunctions2Function#runtime}
    */
    readonly runtime?: string;
    /**
    * Name of the Cloud Build Custom Worker Pool that should be used to build the function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#worker_pool GoogleCloudfunctions2Function#worker_pool}
    */
    readonly workerPool?: string;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#source GoogleCloudfunctions2Function#source}
    */
    readonly source?: GoogleCloudfunctions2FunctionBuildConfigSource;
}
export declare function googleCloudfunctions2FunctionBuildConfigToTerraform(struct?: GoogleCloudfunctions2FunctionBuildConfigOutputReference | GoogleCloudfunctions2FunctionBuildConfig): any;
export declare class GoogleCloudfunctions2FunctionBuildConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudfunctions2FunctionBuildConfig | undefined;
    set internalValue(value: GoogleCloudfunctions2FunctionBuildConfig | undefined);
    get buildAttribute(): string;
    private _dockerRepository?;
    get dockerRepository(): string;
    set dockerRepository(value: string);
    resetDockerRepository(): void;
    get dockerRepositoryInput(): string | undefined;
    private _entryPoint?;
    get entryPoint(): string;
    set entryPoint(value: string);
    resetEntryPoint(): void;
    get entryPointInput(): string | undefined;
    private _environmentVariables?;
    get environmentVariables(): {
        [key: string]: string;
    };
    set environmentVariables(value: {
        [key: string]: string;
    });
    resetEnvironmentVariables(): void;
    get environmentVariablesInput(): {
        [key: string]: string;
    } | undefined;
    private _runtime?;
    get runtime(): string;
    set runtime(value: string);
    resetRuntime(): void;
    get runtimeInput(): string | undefined;
    private _workerPool?;
    get workerPool(): string;
    set workerPool(value: string);
    resetWorkerPool(): void;
    get workerPoolInput(): string | undefined;
    private _source;
    get source(): GoogleCloudfunctions2FunctionBuildConfigSourceOutputReference;
    putSource(value: GoogleCloudfunctions2FunctionBuildConfigSource): void;
    resetSource(): void;
    get sourceInput(): GoogleCloudfunctions2FunctionBuildConfigSource | undefined;
}
export interface GoogleCloudfunctions2FunctionEventTrigger {
    /**
    * Required. The type of event to observe.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#event_type GoogleCloudfunctions2Function#event_type}
    */
    readonly eventType?: string;
    /**
    * The name of a Pub/Sub topic in the same project that will be used
  as the transport topic for the event delivery.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#pubsub_topic GoogleCloudfunctions2Function#pubsub_topic}
    */
    readonly pubsubTopic?: string;
    /**
    * Describes the retry policy in case of function's execution failure.
  Retried execution is charged as any other execution. Possible values: ["RETRY_POLICY_UNSPECIFIED", "RETRY_POLICY_DO_NOT_RETRY", "RETRY_POLICY_RETRY"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#retry_policy GoogleCloudfunctions2Function#retry_policy}
    */
    readonly retryPolicy?: string;
    /**
    * The email of the service account for this function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#service_account_email GoogleCloudfunctions2Function#service_account_email}
    */
    readonly serviceAccountEmail?: string;
    /**
    * The region that the trigger will be in. The trigger will only receive
  events originating in this region. It can be the same
  region as the function, a different region or multi-region, or the global
  region. If not provided, defaults to the same region as the function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#trigger_region GoogleCloudfunctions2Function#trigger_region}
    */
    readonly triggerRegion?: string;
}
export declare function googleCloudfunctions2FunctionEventTriggerToTerraform(struct?: GoogleCloudfunctions2FunctionEventTriggerOutputReference | GoogleCloudfunctions2FunctionEventTrigger): any;
export declare class GoogleCloudfunctions2FunctionEventTriggerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudfunctions2FunctionEventTrigger | undefined;
    set internalValue(value: GoogleCloudfunctions2FunctionEventTrigger | undefined);
    private _eventType?;
    get eventType(): string;
    set eventType(value: string);
    resetEventType(): void;
    get eventTypeInput(): string | undefined;
    private _pubsubTopic?;
    get pubsubTopic(): string;
    set pubsubTopic(value: string);
    resetPubsubTopic(): void;
    get pubsubTopicInput(): string | undefined;
    private _retryPolicy?;
    get retryPolicy(): string;
    set retryPolicy(value: string);
    resetRetryPolicy(): void;
    get retryPolicyInput(): string | undefined;
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string;
    set serviceAccountEmail(value: string);
    resetServiceAccountEmail(): void;
    get serviceAccountEmailInput(): string | undefined;
    get trigger(): string;
    private _triggerRegion?;
    get triggerRegion(): string;
    set triggerRegion(value: string);
    resetTriggerRegion(): void;
    get triggerRegionInput(): string | undefined;
}
export interface GoogleCloudfunctions2FunctionServiceConfig {
    /**
    * Whether 100% of traffic is routed to the latest revision. Defaults to true.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#all_traffic_on_latest_revision GoogleCloudfunctions2Function#all_traffic_on_latest_revision}
    */
    readonly allTrafficOnLatestRevision?: boolean | cdktf.IResolvable;
    /**
    * The amount of memory available for a function.
  Defaults to 256M. Supported units are k, M, G, Mi, Gi. If no unit is
  supplied the value is interpreted as bytes.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#available_memory GoogleCloudfunctions2Function#available_memory}
    */
    readonly availableMemory?: string;
    /**
    * Environment variables that shall be available during function execution.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#environment_variables GoogleCloudfunctions2Function#environment_variables}
    */
    readonly environmentVariables?: {
        [key: string]: string;
    };
    /**
    * Available ingress settings. Defaults to "ALLOW_ALL" if unspecified. Default value: "ALLOW_ALL" Possible values: ["ALLOW_ALL", "ALLOW_INTERNAL_ONLY", "ALLOW_INTERNAL_AND_GCLB"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#ingress_settings GoogleCloudfunctions2Function#ingress_settings}
    */
    readonly ingressSettings?: string;
    /**
    * The limit on the maximum number of function instances that may coexist at a
  given time.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#max_instance_count GoogleCloudfunctions2Function#max_instance_count}
    */
    readonly maxInstanceCount?: number;
    /**
    * The limit on the minimum number of function instances that may coexist at a
  given time.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#min_instance_count GoogleCloudfunctions2Function#min_instance_count}
    */
    readonly minInstanceCount?: number;
    /**
    * Name of the service associated with a Function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#service GoogleCloudfunctions2Function#service}
    */
    readonly service?: string;
    /**
    * The email of the service account for this function.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#service_account_email GoogleCloudfunctions2Function#service_account_email}
    */
    readonly serviceAccountEmail?: string;
    /**
    * The function execution timeout. Execution is considered failed and
  can be terminated if the function is not completed at the end of the
  timeout period. Defaults to 60 seconds.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#timeout_seconds GoogleCloudfunctions2Function#timeout_seconds}
    */
    readonly timeoutSeconds?: number;
    /**
    * The Serverless VPC Access connector that this cloud function can connect to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#vpc_connector GoogleCloudfunctions2Function#vpc_connector}
    */
    readonly vpcConnector?: string;
    /**
    * Available egress settings. Possible values: ["VPC_CONNECTOR_EGRESS_SETTINGS_UNSPECIFIED", "PRIVATE_RANGES_ONLY", "ALL_TRAFFIC"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#vpc_connector_egress_settings GoogleCloudfunctions2Function#vpc_connector_egress_settings}
    */
    readonly vpcConnectorEgressSettings?: string;
}
export declare function googleCloudfunctions2FunctionServiceConfigToTerraform(struct?: GoogleCloudfunctions2FunctionServiceConfigOutputReference | GoogleCloudfunctions2FunctionServiceConfig): any;
export declare class GoogleCloudfunctions2FunctionServiceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudfunctions2FunctionServiceConfig | undefined;
    set internalValue(value: GoogleCloudfunctions2FunctionServiceConfig | undefined);
    private _allTrafficOnLatestRevision?;
    get allTrafficOnLatestRevision(): boolean | cdktf.IResolvable;
    set allTrafficOnLatestRevision(value: boolean | cdktf.IResolvable);
    resetAllTrafficOnLatestRevision(): void;
    get allTrafficOnLatestRevisionInput(): boolean | cdktf.IResolvable | undefined;
    private _availableMemory?;
    get availableMemory(): string;
    set availableMemory(value: string);
    resetAvailableMemory(): void;
    get availableMemoryInput(): string | undefined;
    private _environmentVariables?;
    get environmentVariables(): {
        [key: string]: string;
    };
    set environmentVariables(value: {
        [key: string]: string;
    });
    resetEnvironmentVariables(): void;
    get environmentVariablesInput(): {
        [key: string]: string;
    } | undefined;
    get gcfUri(): string;
    private _ingressSettings?;
    get ingressSettings(): string;
    set ingressSettings(value: string);
    resetIngressSettings(): void;
    get ingressSettingsInput(): string | undefined;
    private _maxInstanceCount?;
    get maxInstanceCount(): number;
    set maxInstanceCount(value: number);
    resetMaxInstanceCount(): void;
    get maxInstanceCountInput(): number | undefined;
    private _minInstanceCount?;
    get minInstanceCount(): number;
    set minInstanceCount(value: number);
    resetMinInstanceCount(): void;
    get minInstanceCountInput(): number | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string;
    set serviceAccountEmail(value: string);
    resetServiceAccountEmail(): void;
    get serviceAccountEmailInput(): string | undefined;
    private _timeoutSeconds?;
    get timeoutSeconds(): number;
    set timeoutSeconds(value: number);
    resetTimeoutSeconds(): void;
    get timeoutSecondsInput(): number | undefined;
    get uri(): string;
    private _vpcConnector?;
    get vpcConnector(): string;
    set vpcConnector(value: string);
    resetVpcConnector(): void;
    get vpcConnectorInput(): string | undefined;
    private _vpcConnectorEgressSettings?;
    get vpcConnectorEgressSettings(): string;
    set vpcConnectorEgressSettings(value: string);
    resetVpcConnectorEgressSettings(): void;
    get vpcConnectorEgressSettingsInput(): string | undefined;
}
export interface GoogleCloudfunctions2FunctionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#create GoogleCloudfunctions2Function#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#delete GoogleCloudfunctions2Function#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function#update GoogleCloudfunctions2Function#update}
    */
    readonly update?: string;
}
export declare function googleCloudfunctions2FunctionTimeoutsToTerraform(struct?: GoogleCloudfunctions2FunctionTimeoutsOutputReference | GoogleCloudfunctions2FunctionTimeouts | cdktf.IResolvable): any;
export declare class GoogleCloudfunctions2FunctionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudfunctions2FunctionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudfunctions2FunctionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function google_cloudfunctions2_function}
*/
export declare class GoogleCloudfunctions2Function extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_cloudfunctions2_function";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloudfunctions2_function google_cloudfunctions2_function} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleCloudfunctions2FunctionConfig
    */
    constructor(scope: Construct, id: string, config: GoogleCloudfunctions2FunctionConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get environment(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    get updateTime(): string;
    private _buildConfig;
    get buildConfig(): GoogleCloudfunctions2FunctionBuildConfigOutputReference;
    putBuildConfig(value: GoogleCloudfunctions2FunctionBuildConfig): void;
    resetBuildConfig(): void;
    get buildConfigInput(): GoogleCloudfunctions2FunctionBuildConfig | undefined;
    private _eventTrigger;
    get eventTrigger(): GoogleCloudfunctions2FunctionEventTriggerOutputReference;
    putEventTrigger(value: GoogleCloudfunctions2FunctionEventTrigger): void;
    resetEventTrigger(): void;
    get eventTriggerInput(): GoogleCloudfunctions2FunctionEventTrigger | undefined;
    private _serviceConfig;
    get serviceConfig(): GoogleCloudfunctions2FunctionServiceConfigOutputReference;
    putServiceConfig(value: GoogleCloudfunctions2FunctionServiceConfig): void;
    resetServiceConfig(): void;
    get serviceConfigInput(): GoogleCloudfunctions2FunctionServiceConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleCloudfunctions2FunctionTimeoutsOutputReference;
    putTimeouts(value: GoogleCloudfunctions2FunctionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleCloudfunctions2FunctionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
