import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComputeGlobalNetworkEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
    * Fully qualified domain name of network endpoint.
  This can only be specified when network_endpoint_type of the NEG is INTERNET_FQDN_PORT.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#fqdn GoogleComputeGlobalNetworkEndpoint#fqdn}
    */
    readonly fqdn?: string;
    /**
    * The global network endpoint group this endpoint is part of.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#global_network_endpoint_group GoogleComputeGlobalNetworkEndpoint#global_network_endpoint_group}
    */
    readonly globalNetworkEndpointGroup: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#id GoogleComputeGlobalNetworkEndpoint#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IPv4 address external endpoint.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#ip_address GoogleComputeGlobalNetworkEndpoint#ip_address}
    */
    readonly ipAddress?: string;
    /**
    * Port number of the external endpoint.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#port GoogleComputeGlobalNetworkEndpoint#port}
    */
    readonly port: number;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#project GoogleComputeGlobalNetworkEndpoint#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#timeouts GoogleComputeGlobalNetworkEndpoint#timeouts}
    */
    readonly timeouts?: GoogleComputeGlobalNetworkEndpointTimeouts;
}
export interface GoogleComputeGlobalNetworkEndpointTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#create GoogleComputeGlobalNetworkEndpoint#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint#delete GoogleComputeGlobalNetworkEndpoint#delete}
    */
    readonly delete?: string;
}
export declare function googleComputeGlobalNetworkEndpointTimeoutsToTerraform(struct?: GoogleComputeGlobalNetworkEndpointTimeoutsOutputReference | GoogleComputeGlobalNetworkEndpointTimeouts | cdktf.IResolvable): any;
export declare class GoogleComputeGlobalNetworkEndpointTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeGlobalNetworkEndpointTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeGlobalNetworkEndpointTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint google_compute_global_network_endpoint}
*/
export declare class GoogleComputeGlobalNetworkEndpoint extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_compute_global_network_endpoint";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_global_network_endpoint google_compute_global_network_endpoint} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComputeGlobalNetworkEndpointConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComputeGlobalNetworkEndpointConfig);
    private _fqdn?;
    get fqdn(): string;
    set fqdn(value: string);
    resetFqdn(): void;
    get fqdnInput(): string | undefined;
    private _globalNetworkEndpointGroup?;
    get globalNetworkEndpointGroup(): string;
    set globalNetworkEndpointGroup(value: string);
    get globalNetworkEndpointGroupInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    resetIpAddress(): void;
    get ipAddressInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleComputeGlobalNetworkEndpointTimeoutsOutputReference;
    putTimeouts(value: GoogleComputeGlobalNetworkEndpointTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComputeGlobalNetworkEndpointTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
