import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComputeNetworkPeeringRoutesConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether to export the custom routes to the peer network.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#export_custom_routes GoogleComputeNetworkPeeringRoutesConfig#export_custom_routes}
    */
    readonly exportCustomRoutes: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#id GoogleComputeNetworkPeeringRoutesConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether to import the custom routes to the peer network.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#import_custom_routes GoogleComputeNetworkPeeringRoutesConfig#import_custom_routes}
    */
    readonly importCustomRoutes: boolean | cdktf.IResolvable;
    /**
    * The name of the primary network for the peering.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#network GoogleComputeNetworkPeeringRoutesConfig#network}
    */
    readonly network: string;
    /**
    * Name of the peering.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#peering GoogleComputeNetworkPeeringRoutesConfig#peering}
    */
    readonly peering: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#project GoogleComputeNetworkPeeringRoutesConfig#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#timeouts GoogleComputeNetworkPeeringRoutesConfig#timeouts}
    */
    readonly timeouts?: GoogleComputeNetworkPeeringRoutesConfigTimeouts;
}
export interface GoogleComputeNetworkPeeringRoutesConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#create GoogleComputeNetworkPeeringRoutesConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#delete GoogleComputeNetworkPeeringRoutesConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config#update GoogleComputeNetworkPeeringRoutesConfig#update}
    */
    readonly update?: string;
}
export declare function googleComputeNetworkPeeringRoutesConfigTimeoutsToTerraform(struct?: GoogleComputeNetworkPeeringRoutesConfigTimeoutsOutputReference | GoogleComputeNetworkPeeringRoutesConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleComputeNetworkPeeringRoutesConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeNetworkPeeringRoutesConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeNetworkPeeringRoutesConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config google_compute_network_peering_routes_config}
*/
export declare class GoogleComputeNetworkPeeringRoutesConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_compute_network_peering_routes_config";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_network_peering_routes_config google_compute_network_peering_routes_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComputeNetworkPeeringRoutesConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComputeNetworkPeeringRoutesConfigConfig);
    private _exportCustomRoutes?;
    get exportCustomRoutes(): boolean | cdktf.IResolvable;
    set exportCustomRoutes(value: boolean | cdktf.IResolvable);
    get exportCustomRoutesInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _importCustomRoutes?;
    get importCustomRoutes(): boolean | cdktf.IResolvable;
    set importCustomRoutes(value: boolean | cdktf.IResolvable);
    get importCustomRoutesInput(): boolean | cdktf.IResolvable | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _peering?;
    get peering(): string;
    set peering(value: string);
    get peeringInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleComputeNetworkPeeringRoutesConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleComputeNetworkPeeringRoutesConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComputeNetworkPeeringRoutesConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
