import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComputeOrganizationSecurityPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * A textual description for the organization security policy.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#description GoogleComputeOrganizationSecurityPolicy#description}
    */
    readonly description?: string;
    /**
    * A textual name of the security policy.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#display_name GoogleComputeOrganizationSecurityPolicy#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#id GoogleComputeOrganizationSecurityPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The parent of this OrganizationSecurityPolicy in the Cloud Resource Hierarchy.
  Format: organizations/{organization_id} or folders/{folder_id}
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#parent GoogleComputeOrganizationSecurityPolicy#parent}
    */
    readonly parent: string;
    /**
    * The type indicates the intended use of the security policy.
  For organization security policies, the only supported type
  is "FIREWALL". Default value: "FIREWALL" Possible values: ["FIREWALL"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#type GoogleComputeOrganizationSecurityPolicy#type}
    */
    readonly type?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#timeouts GoogleComputeOrganizationSecurityPolicy#timeouts}
    */
    readonly timeouts?: GoogleComputeOrganizationSecurityPolicyTimeouts;
}
export interface GoogleComputeOrganizationSecurityPolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#create GoogleComputeOrganizationSecurityPolicy#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#delete GoogleComputeOrganizationSecurityPolicy#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy#update GoogleComputeOrganizationSecurityPolicy#update}
    */
    readonly update?: string;
}
export declare function googleComputeOrganizationSecurityPolicyTimeoutsToTerraform(struct?: GoogleComputeOrganizationSecurityPolicyTimeoutsOutputReference | GoogleComputeOrganizationSecurityPolicyTimeouts | cdktf.IResolvable): any;
export declare class GoogleComputeOrganizationSecurityPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeOrganizationSecurityPolicyTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeOrganizationSecurityPolicyTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy google_compute_organization_security_policy}
*/
export declare class GoogleComputeOrganizationSecurityPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_compute_organization_security_policy";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_organization_security_policy google_compute_organization_security_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComputeOrganizationSecurityPolicyConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComputeOrganizationSecurityPolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    get fingerprint(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    get policyId(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleComputeOrganizationSecurityPolicyTimeoutsOutputReference;
    putTimeouts(value: GoogleComputeOrganizationSecurityPolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComputeOrganizationSecurityPolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
