import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDataCatalogEntryGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Entry group description, which can consist of several sentences or paragraphs that describe entry group contents.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#description GoogleDataCatalogEntryGroup#description}
    */
    readonly description?: string;
    /**
    * A short name to identify the entry group, for example, "analytics data - jan 2011".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#display_name GoogleDataCatalogEntryGroup#display_name}
    */
    readonly displayName?: string;
    /**
    * The id of the entry group to create. The id must begin with a letter or underscore,
  contain only English letters, numbers and underscores, and be at most 64 characters.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#entry_group_id GoogleDataCatalogEntryGroup#entry_group_id}
    */
    readonly entryGroupId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#id GoogleDataCatalogEntryGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#project GoogleDataCatalogEntryGroup#project}
    */
    readonly project?: string;
    /**
    * EntryGroup location region.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#region GoogleDataCatalogEntryGroup#region}
    */
    readonly region?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#timeouts GoogleDataCatalogEntryGroup#timeouts}
    */
    readonly timeouts?: GoogleDataCatalogEntryGroupTimeouts;
}
export interface GoogleDataCatalogEntryGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#create GoogleDataCatalogEntryGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#delete GoogleDataCatalogEntryGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group#update GoogleDataCatalogEntryGroup#update}
    */
    readonly update?: string;
}
export declare function googleDataCatalogEntryGroupTimeoutsToTerraform(struct?: GoogleDataCatalogEntryGroupTimeoutsOutputReference | GoogleDataCatalogEntryGroupTimeouts | cdktf.IResolvable): any;
export declare class GoogleDataCatalogEntryGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataCatalogEntryGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataCatalogEntryGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group google_data_catalog_entry_group}
*/
export declare class GoogleDataCatalogEntryGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_data_catalog_entry_group";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_data_catalog_entry_group google_data_catalog_entry_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDataCatalogEntryGroupConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDataCatalogEntryGroupConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _entryGroupId?;
    get entryGroupId(): string;
    set entryGroupId(value: string);
    get entryGroupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleDataCatalogEntryGroupTimeoutsOutputReference;
    putTimeouts(value: GoogleDataCatalogEntryGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDataCatalogEntryGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
