import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDocumentAiProcessorConfig extends cdktf.TerraformMetaArguments {
    /**
    * The display name. Must be unique.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#display_name GoogleDocumentAiProcessor#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#id GoogleDocumentAiProcessor#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The KMS key used for encryption/decryption in CMEK scenarios. See https://cloud.google.com/security-key-management.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#kms_key_name GoogleDocumentAiProcessor#kms_key_name}
    */
    readonly kmsKeyName?: string;
    /**
    * The location of the resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#location GoogleDocumentAiProcessor#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#project GoogleDocumentAiProcessor#project}
    */
    readonly project?: string;
    /**
    * The type of processor. For possible types see the [official list](https://cloud.google.com/document-ai/docs/reference/rest/v1/projects.locations/fetchProcessorTypes#google.cloud.documentai.v1.DocumentProcessorService.FetchProcessorTypes)
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#type GoogleDocumentAiProcessor#type}
    */
    readonly type: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#timeouts GoogleDocumentAiProcessor#timeouts}
    */
    readonly timeouts?: GoogleDocumentAiProcessorTimeouts;
}
export interface GoogleDocumentAiProcessorTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#create GoogleDocumentAiProcessor#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor#delete GoogleDocumentAiProcessor#delete}
    */
    readonly delete?: string;
}
export declare function googleDocumentAiProcessorTimeoutsToTerraform(struct?: GoogleDocumentAiProcessorTimeoutsOutputReference | GoogleDocumentAiProcessorTimeouts | cdktf.IResolvable): any;
export declare class GoogleDocumentAiProcessorTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDocumentAiProcessorTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDocumentAiProcessorTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor google_document_ai_processor}
*/
export declare class GoogleDocumentAiProcessor extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_document_ai_processor";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_document_ai_processor google_document_ai_processor} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDocumentAiProcessorConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDocumentAiProcessorConfig);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    resetKmsKeyName(): void;
    get kmsKeyNameInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleDocumentAiProcessorTimeoutsOutputReference;
    putTimeouts(value: GoogleDocumentAiProcessorTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDocumentAiProcessorTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
