import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GooglePubsubSubscriptionConfig extends cdktf.TerraformMetaArguments {
    /**
    * This value is the maximum time after a subscriber receives a message
  before the subscriber should acknowledge the message. After message
  delivery but before the ack deadline expires and before the message is
  acknowledged, it is an outstanding message and will not be delivered
  again during that time (on a best-effort basis).
  
  For pull subscriptions, this value is used as the initial value for
  the ack deadline. To override this value for a given message, call
  subscriptions.modifyAckDeadline with the corresponding ackId if using
  pull. The minimum custom deadline you can specify is 10 seconds. The
  maximum custom deadline you can specify is 600 seconds (10 minutes).
  If this parameter is 0, a default value of 10 seconds is used.
  
  For push delivery, this value is also used to set the request timeout
  for the call to the push endpoint.
  
  If the subscriber never acknowledges the message, the Pub/Sub system
  will eventually redeliver the message.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#ack_deadline_seconds GooglePubsubSubscription#ack_deadline_seconds}
    */
    readonly ackDeadlineSeconds?: number;
    /**
    * If 'true', Pub/Sub provides the following guarantees for the delivery
  of a message with a given value of messageId on this Subscriptions':
  
  - The message sent to a subscriber is guaranteed not to be resent before the message's acknowledgement deadline expires.
  
  - An acknowledged message will not be resent to a subscriber.
  
  Note that subscribers may still receive multiple copies of a message when 'enable_exactly_once_delivery'
  is true if the message was published multiple times by a publisher client. These copies are considered distinct by Pub/Sub and have distinct messageId values
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#enable_exactly_once_delivery GooglePubsubSubscription#enable_exactly_once_delivery}
    */
    readonly enableExactlyOnceDelivery?: boolean | cdktf.IResolvable;
    /**
    * If 'true', messages published with the same orderingKey in PubsubMessage will be delivered to
  the subscribers in the order in which they are received by the Pub/Sub system. Otherwise, they
  may be delivered in any order.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#enable_message_ordering GooglePubsubSubscription#enable_message_ordering}
    */
    readonly enableMessageOrdering?: boolean | cdktf.IResolvable;
    /**
    * The subscription only delivers the messages that match the filter.
  Pub/Sub automatically acknowledges the messages that don't match the filter. You can filter messages
  by their attributes. The maximum length of a filter is 256 bytes. After creating the subscription,
  you can't modify the filter.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#filter GooglePubsubSubscription#filter}
    */
    readonly filter?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#id GooglePubsubSubscription#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A set of key/value label pairs to assign to this Subscription.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#labels GooglePubsubSubscription#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * How long to retain unacknowledged messages in the subscription's
  backlog, from the moment a message is published. If
  retain_acked_messages is true, then this also configures the retention
  of acknowledged messages, and thus configures how far back in time a
  subscriptions.seek can be done. Defaults to 7 days. Cannot be more
  than 7 days ('"604800s"') or less than 10 minutes ('"600s"').
  
  A duration in seconds with up to nine fractional digits, terminated
  by 's'. Example: '"600.5s"'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#message_retention_duration GooglePubsubSubscription#message_retention_duration}
    */
    readonly messageRetentionDuration?: string;
    /**
    * Name of the subscription.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#name GooglePubsubSubscription#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#project GooglePubsubSubscription#project}
    */
    readonly project?: string;
    /**
    * Indicates whether to retain acknowledged messages. If 'true', then
  messages are not expunged from the subscription's backlog, even if
  they are acknowledged, until they fall out of the
  messageRetentionDuration window.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#retain_acked_messages GooglePubsubSubscription#retain_acked_messages}
    */
    readonly retainAckedMessages?: boolean | cdktf.IResolvable;
    /**
    * A reference to a Topic resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#topic GooglePubsubSubscription#topic}
    */
    readonly topic: string;
    /**
    * dead_letter_policy block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#dead_letter_policy GooglePubsubSubscription#dead_letter_policy}
    */
    readonly deadLetterPolicy?: GooglePubsubSubscriptionDeadLetterPolicy;
    /**
    * expiration_policy block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#expiration_policy GooglePubsubSubscription#expiration_policy}
    */
    readonly expirationPolicy?: GooglePubsubSubscriptionExpirationPolicy;
    /**
    * push_config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#push_config GooglePubsubSubscription#push_config}
    */
    readonly pushConfig?: GooglePubsubSubscriptionPushConfig;
    /**
    * retry_policy block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#retry_policy GooglePubsubSubscription#retry_policy}
    */
    readonly retryPolicy?: GooglePubsubSubscriptionRetryPolicy;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#timeouts GooglePubsubSubscription#timeouts}
    */
    readonly timeouts?: GooglePubsubSubscriptionTimeouts;
}
export interface GooglePubsubSubscriptionDeadLetterPolicy {
    /**
    * The name of the topic to which dead letter messages should be published.
  Format is 'projects/{project}/topics/{topic}'.
  
  The Cloud Pub/Sub service account associated with the enclosing subscription's
  parent project (i.e.,
  service-{project_number}@gcp-sa-pubsub.iam.gserviceaccount.com) must have
  permission to Publish() to this topic.
  
  The operation will fail if the topic does not exist.
  Users should ensure that there is a subscription attached to this topic
  since messages published to a topic with no subscriptions are lost.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#dead_letter_topic GooglePubsubSubscription#dead_letter_topic}
    */
    readonly deadLetterTopic?: string;
    /**
    * The maximum number of delivery attempts for any message. The value must be
  between 5 and 100.
  
  The number of delivery attempts is defined as 1 + (the sum of number of
  NACKs and number of times the acknowledgement deadline has been exceeded for the message).
  
  A NACK is any call to ModifyAckDeadline with a 0 deadline. Note that
  client libraries may automatically extend ack_deadlines.
  
  This field will be honored on a best effort basis.
  
  If this parameter is 0, a default value of 5 is used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#max_delivery_attempts GooglePubsubSubscription#max_delivery_attempts}
    */
    readonly maxDeliveryAttempts?: number;
}
export declare function googlePubsubSubscriptionDeadLetterPolicyToTerraform(struct?: GooglePubsubSubscriptionDeadLetterPolicyOutputReference | GooglePubsubSubscriptionDeadLetterPolicy): any;
export declare class GooglePubsubSubscriptionDeadLetterPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePubsubSubscriptionDeadLetterPolicy | undefined;
    set internalValue(value: GooglePubsubSubscriptionDeadLetterPolicy | undefined);
    private _deadLetterTopic?;
    get deadLetterTopic(): string;
    set deadLetterTopic(value: string);
    resetDeadLetterTopic(): void;
    get deadLetterTopicInput(): string | undefined;
    private _maxDeliveryAttempts?;
    get maxDeliveryAttempts(): number;
    set maxDeliveryAttempts(value: number);
    resetMaxDeliveryAttempts(): void;
    get maxDeliveryAttemptsInput(): number | undefined;
}
export interface GooglePubsubSubscriptionExpirationPolicy {
    /**
    * Specifies the "time-to-live" duration for an associated resource. The
  resource expires if it is not active for a period of ttl.
  If ttl is not set, the associated resource never expires.
  A duration in seconds with up to nine fractional digits, terminated by 's'.
  Example - "3.5s".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#ttl GooglePubsubSubscription#ttl}
    */
    readonly ttl: string;
}
export declare function googlePubsubSubscriptionExpirationPolicyToTerraform(struct?: GooglePubsubSubscriptionExpirationPolicyOutputReference | GooglePubsubSubscriptionExpirationPolicy): any;
export declare class GooglePubsubSubscriptionExpirationPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePubsubSubscriptionExpirationPolicy | undefined;
    set internalValue(value: GooglePubsubSubscriptionExpirationPolicy | undefined);
    private _ttl?;
    get ttl(): string;
    set ttl(value: string);
    get ttlInput(): string | undefined;
}
export interface GooglePubsubSubscriptionPushConfigOidcToken {
    /**
    * Audience to be used when generating OIDC token. The audience claim
  identifies the recipients that the JWT is intended for. The audience
  value is a single case-sensitive string. Having multiple values (array)
  for the audience field is not supported. More info about the OIDC JWT
  token audience here: https://tools.ietf.org/html/rfc7519#section-4.1.3
  Note: if not specified, the Push endpoint URL will be used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#audience GooglePubsubSubscription#audience}
    */
    readonly audience?: string;
    /**
    * Service account email to be used for generating the OIDC token.
  The caller (for subscriptions.create, subscriptions.patch, and
  subscriptions.modifyPushConfig RPCs) must have the
  iam.serviceAccounts.actAs permission for the service account.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#service_account_email GooglePubsubSubscription#service_account_email}
    */
    readonly serviceAccountEmail: string;
}
export declare function googlePubsubSubscriptionPushConfigOidcTokenToTerraform(struct?: GooglePubsubSubscriptionPushConfigOidcTokenOutputReference | GooglePubsubSubscriptionPushConfigOidcToken): any;
export declare class GooglePubsubSubscriptionPushConfigOidcTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePubsubSubscriptionPushConfigOidcToken | undefined;
    set internalValue(value: GooglePubsubSubscriptionPushConfigOidcToken | undefined);
    private _audience?;
    get audience(): string;
    set audience(value: string);
    resetAudience(): void;
    get audienceInput(): string | undefined;
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string;
    set serviceAccountEmail(value: string);
    get serviceAccountEmailInput(): string | undefined;
}
export interface GooglePubsubSubscriptionPushConfig {
    /**
    * Endpoint configuration attributes.
  
  Every endpoint has a set of API supported attributes that can
  be used to control different aspects of the message delivery.
  
  The currently supported attribute is x-goog-version, which you
  can use to change the format of the pushed message. This
  attribute indicates the version of the data expected by
  the endpoint. This controls the shape of the pushed message
  (i.e., its fields and metadata). The endpoint version is
  based on the version of the Pub/Sub API.
  
  If not present during the subscriptions.create call,
  it will default to the version of the API used to make
  such call. If not present during a subscriptions.modifyPushConfig
  call, its value will not be changed. subscriptions.get
  calls will always return a valid version, even if the
  subscription was created without this attribute.
  
  The possible values for this attribute are:
  
  - v1beta1: uses the push format defined in the v1beta1 Pub/Sub API.
  - v1 or v1beta2: uses the push format defined in the v1 Pub/Sub API.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#attributes GooglePubsubSubscription#attributes}
    */
    readonly attributes?: {
        [key: string]: string;
    };
    /**
    * A URL locating the endpoint to which messages should be pushed.
  For example, a Webhook endpoint might use
  "https://example.com/push".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#push_endpoint GooglePubsubSubscription#push_endpoint}
    */
    readonly pushEndpoint: string;
    /**
    * oidc_token block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#oidc_token GooglePubsubSubscription#oidc_token}
    */
    readonly oidcToken?: GooglePubsubSubscriptionPushConfigOidcToken;
}
export declare function googlePubsubSubscriptionPushConfigToTerraform(struct?: GooglePubsubSubscriptionPushConfigOutputReference | GooglePubsubSubscriptionPushConfig): any;
export declare class GooglePubsubSubscriptionPushConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePubsubSubscriptionPushConfig | undefined;
    set internalValue(value: GooglePubsubSubscriptionPushConfig | undefined);
    private _attributes?;
    get attributes(): {
        [key: string]: string;
    };
    set attributes(value: {
        [key: string]: string;
    });
    resetAttributes(): void;
    get attributesInput(): {
        [key: string]: string;
    } | undefined;
    private _pushEndpoint?;
    get pushEndpoint(): string;
    set pushEndpoint(value: string);
    get pushEndpointInput(): string | undefined;
    private _oidcToken;
    get oidcToken(): GooglePubsubSubscriptionPushConfigOidcTokenOutputReference;
    putOidcToken(value: GooglePubsubSubscriptionPushConfigOidcToken): void;
    resetOidcToken(): void;
    get oidcTokenInput(): GooglePubsubSubscriptionPushConfigOidcToken | undefined;
}
export interface GooglePubsubSubscriptionRetryPolicy {
    /**
    * The maximum delay between consecutive deliveries of a given message. Value should be between 0 and 600 seconds. Defaults to 600 seconds.
  A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#maximum_backoff GooglePubsubSubscription#maximum_backoff}
    */
    readonly maximumBackoff?: string;
    /**
    * The minimum delay between consecutive deliveries of a given message. Value should be between 0 and 600 seconds. Defaults to 10 seconds.
  A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#minimum_backoff GooglePubsubSubscription#minimum_backoff}
    */
    readonly minimumBackoff?: string;
}
export declare function googlePubsubSubscriptionRetryPolicyToTerraform(struct?: GooglePubsubSubscriptionRetryPolicyOutputReference | GooglePubsubSubscriptionRetryPolicy): any;
export declare class GooglePubsubSubscriptionRetryPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePubsubSubscriptionRetryPolicy | undefined;
    set internalValue(value: GooglePubsubSubscriptionRetryPolicy | undefined);
    private _maximumBackoff?;
    get maximumBackoff(): string;
    set maximumBackoff(value: string);
    resetMaximumBackoff(): void;
    get maximumBackoffInput(): string | undefined;
    private _minimumBackoff?;
    get minimumBackoff(): string;
    set minimumBackoff(value: string);
    resetMinimumBackoff(): void;
    get minimumBackoffInput(): string | undefined;
}
export interface GooglePubsubSubscriptionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#create GooglePubsubSubscription#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#delete GooglePubsubSubscription#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription#update GooglePubsubSubscription#update}
    */
    readonly update?: string;
}
export declare function googlePubsubSubscriptionTimeoutsToTerraform(struct?: GooglePubsubSubscriptionTimeoutsOutputReference | GooglePubsubSubscriptionTimeouts | cdktf.IResolvable): any;
export declare class GooglePubsubSubscriptionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePubsubSubscriptionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GooglePubsubSubscriptionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription google_pubsub_subscription}
*/
export declare class GooglePubsubSubscription extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_pubsub_subscription";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_pubsub_subscription google_pubsub_subscription} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GooglePubsubSubscriptionConfig
    */
    constructor(scope: Construct, id: string, config: GooglePubsubSubscriptionConfig);
    private _ackDeadlineSeconds?;
    get ackDeadlineSeconds(): number;
    set ackDeadlineSeconds(value: number);
    resetAckDeadlineSeconds(): void;
    get ackDeadlineSecondsInput(): number | undefined;
    private _enableExactlyOnceDelivery?;
    get enableExactlyOnceDelivery(): boolean | cdktf.IResolvable;
    set enableExactlyOnceDelivery(value: boolean | cdktf.IResolvable);
    resetEnableExactlyOnceDelivery(): void;
    get enableExactlyOnceDeliveryInput(): boolean | cdktf.IResolvable | undefined;
    private _enableMessageOrdering?;
    get enableMessageOrdering(): boolean | cdktf.IResolvable;
    set enableMessageOrdering(value: boolean | cdktf.IResolvable);
    resetEnableMessageOrdering(): void;
    get enableMessageOrderingInput(): boolean | cdktf.IResolvable | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _messageRetentionDuration?;
    get messageRetentionDuration(): string;
    set messageRetentionDuration(value: string);
    resetMessageRetentionDuration(): void;
    get messageRetentionDurationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _retainAckedMessages?;
    get retainAckedMessages(): boolean | cdktf.IResolvable;
    set retainAckedMessages(value: boolean | cdktf.IResolvable);
    resetRetainAckedMessages(): void;
    get retainAckedMessagesInput(): boolean | cdktf.IResolvable | undefined;
    private _topic?;
    get topic(): string;
    set topic(value: string);
    get topicInput(): string | undefined;
    private _deadLetterPolicy;
    get deadLetterPolicy(): GooglePubsubSubscriptionDeadLetterPolicyOutputReference;
    putDeadLetterPolicy(value: GooglePubsubSubscriptionDeadLetterPolicy): void;
    resetDeadLetterPolicy(): void;
    get deadLetterPolicyInput(): GooglePubsubSubscriptionDeadLetterPolicy | undefined;
    private _expirationPolicy;
    get expirationPolicy(): GooglePubsubSubscriptionExpirationPolicyOutputReference;
    putExpirationPolicy(value: GooglePubsubSubscriptionExpirationPolicy): void;
    resetExpirationPolicy(): void;
    get expirationPolicyInput(): GooglePubsubSubscriptionExpirationPolicy | undefined;
    private _pushConfig;
    get pushConfig(): GooglePubsubSubscriptionPushConfigOutputReference;
    putPushConfig(value: GooglePubsubSubscriptionPushConfig): void;
    resetPushConfig(): void;
    get pushConfigInput(): GooglePubsubSubscriptionPushConfig | undefined;
    private _retryPolicy;
    get retryPolicy(): GooglePubsubSubscriptionRetryPolicyOutputReference;
    putRetryPolicy(value: GooglePubsubSubscriptionRetryPolicy): void;
    resetRetryPolicy(): void;
    get retryPolicyInput(): GooglePubsubSubscriptionRetryPolicy | undefined;
    private _timeouts;
    get timeouts(): GooglePubsubSubscriptionTimeoutsOutputReference;
    putTimeouts(value: GooglePubsubSubscriptionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GooglePubsubSubscriptionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
