import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSecretManagerSecretVersionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The current state of the SecretVersion.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version#enabled GoogleSecretManagerSecretVersion#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version#id GoogleSecretManagerSecretVersion#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Secret Manager secret resource
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version#secret GoogleSecretManagerSecretVersion#secret}
    */
    readonly secret: string;
    /**
    * The secret data. Must be no larger than 64KiB.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version#secret_data GoogleSecretManagerSecretVersion#secret_data}
    */
    readonly secretData: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version#timeouts GoogleSecretManagerSecretVersion#timeouts}
    */
    readonly timeouts?: GoogleSecretManagerSecretVersionTimeouts;
}
export interface GoogleSecretManagerSecretVersionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version#create GoogleSecretManagerSecretVersion#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version#delete GoogleSecretManagerSecretVersion#delete}
    */
    readonly delete?: string;
}
export declare function googleSecretManagerSecretVersionTimeoutsToTerraform(struct?: GoogleSecretManagerSecretVersionTimeoutsOutputReference | GoogleSecretManagerSecretVersionTimeouts | cdktf.IResolvable): any;
export declare class GoogleSecretManagerSecretVersionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSecretManagerSecretVersionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleSecretManagerSecretVersionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version google_secret_manager_secret_version}
*/
export declare class GoogleSecretManagerSecretVersion extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_secret_manager_secret_version";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret_version google_secret_manager_secret_version} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSecretManagerSecretVersionConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSecretManagerSecretVersionConfig);
    get createTime(): string;
    get destroyTime(): string;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _secret?;
    get secret(): string;
    set secret(value: string);
    get secretInput(): string | undefined;
    private _secretData?;
    get secretData(): string;
    set secretData(value: string);
    get secretDataInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleSecretManagerSecretVersionTimeoutsOutputReference;
    putTimeouts(value: GoogleSecretManagerSecretVersionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleSecretManagerSecretVersionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
